@@ -1,6 +1,7 @@
 package agent
 
 import (
+	"bytes"
 	"flag"
 	"fmt"
 	"os"
@@ -9,6 +10,7 @@ import (
 	"testing"
 
 	pkgerrors "github.com/pkg/errors"
+	"github.com/sirupsen/logrus"
 	"github.com/stretchr/testify/require"
 	"github.com/urfave/cli/v2"
 
@@ -520,3 +522,23 @@ func TestPrintNewOrUpdatedApps(t *testing.T) {
 
 	printNewOrUpdatedApps(newApps, oldApps)
 }
+
+// The monitor periodically searches for the Kea/Bind9 instances. Usually, at
+// least one application should be available. If no monitored app is found,
+// the Stork prints the warning message to indicate that something unexpected
+// happened.
+func TestPrintNewOrUpdatedAppsNoAppDetectedWarning(t *testing.T) {
+	// Arrange
+	output := logrus.StandardLogger().Out
+	defer func() {
+		logrus.SetOutput(output)
+	}()
+	var buffer bytes.Buffer
+	logrus.SetOutput(&buffer)
+
+	// Act
+	printNewOrUpdatedApps([]App{}, []App{})
+
+	// Assert
+	require.Contains(t, buffer.String(), "No Kea nor Bind9 app detected for monitoring")
+}
