@@ -192,7 +192,25 @@ func getTestConfigWithIPv6GlobalHosts(t *testing.T) *dbmodel.KeaConfig {
                     "duid": "ff:ff:ff:ff",
                     "ip-addresses": [ "2001:db8:1::11" ],
                     "prefixes": [ "3001::/64" ],
-                    "hostname": "foo.example.org"
+                    "hostname": "foo.example.org",
+					"option-data": [
+						{
+							"code": 1024,
+							"space": "dhcp6"
+						},
+						{
+							"code": 1025,
+							"space": "option-1024"
+						},
+						{
+							"code": 1026,
+							"space": "option-1024.1025"
+						},
+						{
+							"code": 1027,
+							"space": "option-1024.1025.1026"
+						}
+					]
                 }
             ],
             "hooks-libraries": [
@@ -480,7 +498,7 @@ func testHost(t *testing.T, reservation interface{}, identifier string, address
 	)
 	daemon := dbmodel.NewKeaDaemon(dbmodel.DaemonNameDHCPv4, true)
 	if r, ok := reservation.(keaconfig.Reservation); ok {
-		host, err = dbmodel.NewHostFromKeaConfigReservation(r, daemon, dbmodel.HostDataSourceConfig)
+		host, err = dbmodel.NewHostFromKeaConfigReservation(r, daemon, dbmodel.HostDataSourceConfig, dbmodel.NewDHCPOptionDefinitionLookup())
 		require.NoError(t, err)
 	} else {
 		h := reservation.(dbmodel.Host)
@@ -574,11 +592,13 @@ func TestDetectHostsFromConfig(t *testing.T) {
 		v6hosts []dbmodel.Host
 	)
 
+	lookup := dbmodel.NewDHCPOptionDefinitionLookup()
+
 	// Detect global hosts in the configurations of the app.
-	v4hosts, err = detectGlobalHostsFromConfig(db, app.Daemons[0])
+	v4hosts, err = detectGlobalHostsFromConfig(db, app.Daemons[0], lookup)
 	require.NoError(t, err)
 	hosts = append(hosts, v4hosts...)
-	v6hosts, err = detectGlobalHostsFromConfig(db, app.Daemons[1])
+	v6hosts, err = detectGlobalHostsFromConfig(db, app.Daemons[1], lookup)
 	require.NoError(t, err)
 	hosts = append(hosts, v6hosts...)
 	require.Len(t, hosts, 4)
@@ -605,7 +625,7 @@ func TestDetectHostsFromConfig(t *testing.T) {
 	// Run the detection again.
 	hosts = []dbmodel.Host{}
 	for i := range app.Daemons {
-		detectedHosts, err := detectGlobalHostsFromConfig(db, app.Daemons[i])
+		detectedHosts, err := detectGlobalHostsFromConfig(db, app.Daemons[i], lookup)
 		require.NoError(t, err)
 		hosts = append(hosts, detectedHosts...)
 	}
@@ -677,7 +697,8 @@ func TestDetectHostsSameConfig(t *testing.T) {
 
 	// Both configurations are indicated to be the same so the hosts should not
 	// be committed to the database.
-	err = CommitAppIntoDB(db, &app, fec, state)
+	lookup := dbmodel.NewDHCPOptionDefinitionLookup()
+	err = CommitAppIntoDB(db, &app, fec, state, lookup)
 	require.NoError(t, err)
 
 	// Make sure that no hosts have been added.
@@ -691,7 +712,7 @@ func TestDetectHostsSameConfig(t *testing.T) {
 			dbmodel.DaemonNameDHCPv4: true,
 		},
 	}
-	err = CommitAppIntoDB(db, &app, fec, state)
+	err = CommitAppIntoDB(db, &app, fec, state, lookup)
 	require.NoError(t, err)
 
 	// The hosts should have been added for the DHCPv6 daemon.
@@ -747,7 +768,8 @@ func TestGetPageFromHostCmds(t *testing.T) {
 	require.NoError(t, err)
 	app.Machine = m
 
-	err = CommitAppIntoDB(db, &app, fec, nil)
+	lookup := dbmodel.NewDHCPOptionDefinitionLookup()
+	err = CommitAppIntoDB(db, &app, fec, nil, lookup)
 	require.NoError(t, err)
 
 	fa := agentcommtest.NewFakeAgents(mockReservationGetPage, nil)
@@ -1264,18 +1286,19 @@ func TestFetchHostsFromHostCmds(t *testing.T) {
 	require.NoError(t, err)
 	app.Machine = m
 
-	err = CommitAppIntoDB(db, &app, fec, nil)
+	lookup := dbmodel.NewDHCPOptionDefinitionLookup()
+	err = CommitAppIntoDB(db, &app, fec, nil, lookup)
 	require.NoError(t, err)
 
 	fa := agentcommtest.NewFakeAgents(mockReservationGetPage, nil)
 	fd := &storktest.FakeDispatcher{}
 
 	// The puller requires fetch interval to be present in the database.
-	err = dbmodel.InitializeSettings(db)
+	err = dbmodel.InitializeSettings(db, 0)
 	require.NoError(t, err)
 
 	// Create the puller.
-	puller, err := NewHostsPuller(db, fa, fd)
+	puller, err := NewHostsPuller(db, fa, fd, lookup)
 	require.NoError(t, err)
 	require.NotNil(t, puller)
 
@@ -1318,11 +1341,12 @@ func TestNewHostsPuller(t *testing.T) {
 	defer teardown()
 
 	// The puller requires fetch interval to be present in the database.
-	err := dbmodel.InitializeSettings(db)
+	err := dbmodel.InitializeSettings(db, 0)
 	require.NoError(t, err)
 
 	fd := &storktest.FakeDispatcher{}
-	puller, err := NewHostsPuller(db, nil, fd)
+	lookup := dbmodel.NewDHCPOptionDefinitionLookup()
+	puller, err := NewHostsPuller(db, nil, fd, lookup)
 	require.NoError(t, err)
 	require.NotNil(t, puller)
 	puller.Shutdown()
@@ -1375,19 +1399,20 @@ func TestPullHostsIntoDB(t *testing.T) {
 	require.NoError(t, err)
 	app.Machine = m
 
-	err = CommitAppIntoDB(db, &app, fec, nil)
+	lookup := dbmodel.NewDHCPOptionDefinitionLookup()
+	err = CommitAppIntoDB(db, &app, fec, nil, lookup)
 	require.NoError(t, err)
 
 	fa := agentcommtest.NewFakeAgents(mockReservationGetPage, nil)
 
 	// The puller requires fetch interval to be present in the database.
-	err = dbmodel.InitializeSettings(db)
+	err = dbmodel.InitializeSettings(db, 0)
 	require.NoError(t, err)
 
 	// Create the puller. It is configured to fetch the data every 60 seconds
 	// so we'd rather call it periodically.
 	fd := &storktest.FakeDispatcher{}
-	puller, err := NewHostsPuller(db, fa, fd)
+	puller, err := NewHostsPuller(db, fa, fd, lookup)
 	require.NoError(t, err)
 	require.NotNil(t, puller)
 
@@ -1458,7 +1483,8 @@ func TestReduceHostsIntoDB(t *testing.T) {
 	require.NoError(t, err)
 	app.Machine = m
 
-	err = CommitAppIntoDB(db, &app, fec, nil)
+	lookup := dbmodel.NewDHCPOptionDefinitionLookup()
+	err = CommitAppIntoDB(db, &app, fec, nil, lookup)
 	require.NoError(t, err)
 
 	// Create server which returns two hosts at the first attempt and
@@ -1466,12 +1492,12 @@ func TestReduceHostsIntoDB(t *testing.T) {
 	fa := agentcommtest.NewFakeAgents(mockReservationGetPageReduceHosts, nil)
 
 	// The puller requires fetch interval to be present in the database.
-	err = dbmodel.InitializeSettings(db)
+	err = dbmodel.InitializeSettings(db, 0)
 	require.NoError(t, err)
 
 	// Create the puller instance.
 	fd := &storktest.FakeDispatcher{}
-	puller, err := NewHostsPuller(db, fa, fd)
+	puller, err := NewHostsPuller(db, fa, fd, lookup)
 	require.NoError(t, err)
 	require.NotNil(t, puller)
 
@@ -1485,7 +1511,7 @@ func TestReduceHostsIntoDB(t *testing.T) {
 	require.Len(t, hosts, 2)
 
 	// Repeat the same test, but this time only one host should be returned.
-	puller, err = NewHostsPuller(db, fa, fd)
+	puller, err = NewHostsPuller(db, fa, fd, lookup)
 	require.NoError(t, err)
 	require.NotNil(t, puller)
 
@@ -1541,18 +1567,19 @@ func TestPartialHostsChange(t *testing.T) {
 	app.Machine = m
 
 	fec := &storktest.FakeEventCenter{}
-	err = CommitAppIntoDB(db, &app, fec, nil)
+	lookup := dbmodel.NewDHCPOptionDefinitionLookup()
+	err = CommitAppIntoDB(db, &app, fec, nil, lookup)
 	require.NoError(t, err)
 
 	fa := agentcommtest.NewFakeAgents(mockReservationGetPagePartialChange, nil)
 
 	// The puller requires fetch interval to be present in the database.
-	err = dbmodel.InitializeSettings(db)
+	err = dbmodel.InitializeSettings(db, 0)
 	require.NoError(t, err)
 
 	// Create the puller instance.
 	fd := &storktest.FakeDispatcher{}
-	puller, err := NewHostsPuller(db, fa, fd)
+	puller, err := NewHostsPuller(db, fa, fd, lookup)
 	require.NoError(t, err)
 	require.NotNil(t, puller)
 
@@ -1638,17 +1665,18 @@ func TestSkipPullingHostsIntoDB(t *testing.T) {
 	require.NoError(t, err)
 	app.Machine = m
 
-	err = CommitAppIntoDB(db, &app, fec, nil)
+	lookup := dbmodel.NewDHCPOptionDefinitionLookup()
+	err = CommitAppIntoDB(db, &app, fec, nil, lookup)
 	require.NoError(t, err)
 
 	fa := agentcommtest.NewFakeAgents(mockReservationGetPage, nil)
 
 	// The puller requires fetch interval to be present in the database.
-	err = dbmodel.InitializeSettings(db)
+	err = dbmodel.InitializeSettings(db, 0)
 	require.NoError(t, err)
 
 	fd := &storktest.FakeDispatcher{}
-	puller, err := NewHostsPuller(db, fa, fd)
+	puller, err := NewHostsPuller(db, fa, fd, lookup)
 	require.NoError(t, err)
 	require.NotNil(t, puller)
 
@@ -1743,7 +1771,8 @@ func TestUpdateHost(t *testing.T) {
 	require.NoError(t, err)
 	app.Machine = m
 
-	_ = CommitAppIntoDB(db, &app, fec, nil)
+	lookup := dbmodel.NewDHCPOptionDefinitionLookup()
+	_ = CommitAppIntoDB(db, &app, fec, nil, lookup)
 
 	fa := agentcommtest.NewFakeAgents(func(callNo int, cmdResponses []interface{}) {
 		var json string
@@ -1810,12 +1839,12 @@ func TestUpdateHost(t *testing.T) {
 	}, nil)
 
 	// The puller requires fetch interval to be present in the database.
-	err = dbmodel.InitializeSettings(db)
+	err = dbmodel.InitializeSettings(db, 0)
 	require.NoError(t, err)
 
 	// Create the puller instance.
 	fd := &storktest.FakeDispatcher{}
-	puller, err := NewHostsPuller(db, fa, fd)
+	puller, err := NewHostsPuller(db, fa, fd, lookup)
 	require.NoError(t, err)
 	require.NotNil(t, puller)
 
