@@ -129,7 +129,8 @@ func TestDetectNetworksWhenAppCommitted(t *testing.T) {
             }
         }`
 	app := createAppWithSubnets(t, db, 0, v4Config, v6Config)
-	err := CommitAppIntoDB(db, app, fec, nil)
+	lookup := dbmodel.NewDHCPOptionDefinitionLookup()
+	err := CommitAppIntoDB(db, app, fec, nil, lookup)
 	require.NoError(t, err)
 
 	// The configuration didn't include any shared network, so it should
@@ -211,7 +212,7 @@ func TestDetectNetworksWhenAppCommitted(t *testing.T) {
             }
         }`
 	app = createAppWithSubnets(t, db, 1, v4Config, "")
-	err = CommitAppIntoDB(db, app, fec, nil)
+	err = CommitAppIntoDB(db, app, fec, nil, lookup)
 	require.NoError(t, err)
 
 	// There should be one shared network in the database.
@@ -276,7 +277,7 @@ func TestDetectNetworksWhenAppCommitted(t *testing.T) {
             }
         }`
 	app = createAppWithSubnets(t, db, 2, v4Config, "")
-	err = CommitAppIntoDB(db, app, fec, nil)
+	err = CommitAppIntoDB(db, app, fec, nil, lookup)
 	require.NoError(t, err)
 
 	// There should still be just one shared network.
@@ -291,7 +292,7 @@ func TestDetectNetworksWhenAppCommitted(t *testing.T) {
 
 	// Adding the same subnet again should be fine and should not result in
 	// any conflicts.
-	err = CommitAppIntoDB(db, app, fec, nil)
+	err = CommitAppIntoDB(db, app, fec, nil, lookup)
 	require.NoError(t, err)
 
 	networks, err = dbmodel.GetAllSharedNetworks(db, 4)
@@ -347,7 +348,8 @@ func TestCommitAppSameConfigs(t *testing.T) {
 		},
 	}
 	app := createAppWithSubnets(t, db, 0, v4Config, v6Config)
-	err := CommitAppIntoDB(db, app, fec, state)
+	lookup := dbmodel.NewDHCPOptionDefinitionLookup()
+	err := CommitAppIntoDB(db, app, fec, state, lookup)
 	require.NoError(t, err)
 
 	// There should be no IPv4 subnets because they should have been skipped.
@@ -394,7 +396,8 @@ func TestDetectNetworksMoveSubnetsAround(t *testing.T) {
             }
         }`
 	app := createAppWithSubnets(t, db, 0, v4Config, "")
-	err := CommitAppIntoDB(db, app, fec, nil)
+	lookup := dbmodel.NewDHCPOptionDefinitionLookup()
+	err := CommitAppIntoDB(db, app, fec, nil, lookup)
 	require.NoError(t, err)
 
 	// Shared network should have been created along with the subnets.
@@ -439,7 +442,7 @@ func TestDetectNetworksMoveSubnetsAround(t *testing.T) {
 	require.NoError(t, err)
 
 	app.Daemons[0].KeaDaemon.Config = kea4Config0
-	err = CommitAppIntoDB(db, app, fec, nil)
+	err = CommitAppIntoDB(db, app, fec, nil, lookup)
 	require.NoError(t, err)
 
 	// The shared network should still be there.
@@ -482,7 +485,7 @@ func TestDetectNetworksMoveSubnetsAround(t *testing.T) {
 	require.NoError(t, err)
 
 	app.Daemons[0].KeaDaemon.Config = kea4Config1
-	err = CommitAppIntoDB(db, app, fec, nil)
+	err = CommitAppIntoDB(db, app, fec, nil, lookup)
 	require.NoError(t, err)
 
 	// The shared network should now be gone.
@@ -492,7 +495,7 @@ func TestDetectNetworksMoveSubnetsAround(t *testing.T) {
 
 	// Revert to the original config.
 	app.Daemons[0].KeaDaemon.Config = kea4Config0
-	err = CommitAppIntoDB(db, app, fec, nil)
+	err = CommitAppIntoDB(db, app, fec, nil, lookup)
 	require.NoError(t, err)
 
 	// The shared network should be there.
@@ -513,6 +516,7 @@ func TestDetectNetworksRemoveOrphanedSubnets(t *testing.T) {
 	db, _, teardown := dbtest.SetupDatabaseTestCase(t)
 	defer teardown()
 	fec := &storktest.FakeEventCenter{}
+	lookup := dbmodel.NewDHCPOptionDefinitionLookup()
 	apps := make([]*dbmodel.App, 2)
 
 	// Create a configuration with a single subnet.
@@ -529,7 +533,7 @@ func TestDetectNetworksRemoveOrphanedSubnets(t *testing.T) {
 	// Assign the same configuration to two apps.
 	for i := 0; i < len(apps); i++ {
 		apps[i] = createAppWithSubnets(t, db, int64(i), v4Config, "")
-		err := CommitAppIntoDB(db, apps[i], fec, nil)
+		err := CommitAppIntoDB(db, apps[i], fec, nil, lookup)
 		require.NoError(t, err)
 	}
 
@@ -553,7 +557,7 @@ func TestDetectNetworksRemoveOrphanedSubnets(t *testing.T) {
 	require.NoError(t, err)
 
 	apps[0].Daemons[0].KeaDaemon.Config = kea4Config
-	err = CommitAppIntoDB(db, apps[0], fec, nil)
+	err = CommitAppIntoDB(db, apps[0], fec, nil, lookup)
 	require.NoError(t, err)
 
 	// There should still be two subnets in the database, each owned
@@ -566,7 +570,7 @@ func TestDetectNetworksRemoveOrphanedSubnets(t *testing.T) {
 
 	// Update the second app to use the second subnet.
 	apps[1].Daemons[0].KeaDaemon.Config = kea4Config
-	err = CommitAppIntoDB(db, apps[1], fec, nil)
+	err = CommitAppIntoDB(db, apps[1], fec, nil, lookup)
 	require.NoError(t, err)
 
 	// The first subnet should have been removed because the second
@@ -584,6 +588,7 @@ func TestDetectNetworksRemoveOrphanedHosts(t *testing.T) {
 	db, _, teardown := dbtest.SetupDatabaseTestCase(t)
 	defer teardown()
 	fec := &storktest.FakeEventCenter{}
+	lookup := dbmodel.NewDHCPOptionDefinitionLookup()
 	apps := make([]*dbmodel.App, 2)
 
 	// Create a configuration with a single host reservation.
@@ -606,7 +611,7 @@ func TestDetectNetworksRemoveOrphanedHosts(t *testing.T) {
 	// Assign the same configuration to two apps.
 	for i := 0; i < len(apps); i++ {
 		apps[i] = createAppWithSubnets(t, db, int64(i), v4Config, "")
-		err := CommitAppIntoDB(db, apps[i], fec, nil)
+		err := CommitAppIntoDB(db, apps[i], fec, nil, lookup)
 		require.NoError(t, err)
 	}
 
@@ -639,7 +644,7 @@ func TestDetectNetworksRemoveOrphanedHosts(t *testing.T) {
 	require.NoError(t, err)
 
 	apps[0].Daemons[0].KeaDaemon.Config = kea4Config
-	err = CommitAppIntoDB(db, apps[0], fec, nil)
+	err = CommitAppIntoDB(db, apps[0], fec, nil, lookup)
 	require.NoError(t, err)
 
 	// There should be two hosts in the database, each owned by a
@@ -650,7 +655,7 @@ func TestDetectNetworksRemoveOrphanedHosts(t *testing.T) {
 
 	// Update the second app to use the second reservation.
 	apps[1].Daemons[0].KeaDaemon.Config = kea4Config
-	err = CommitAppIntoDB(db, apps[1], fec, nil)
+	err = CommitAppIntoDB(db, apps[1], fec, nil, lookup)
 	require.NoError(t, err)
 
 	// The first host should have been removed because the second
