@@ -2,6 +2,8 @@ package configreview
 
 import (
 	"fmt"
+	"sort"
+	"strings"
 
 	"github.com/pkg/errors"
 	keaconfig "isc.org/stork/appcfg/kea"
@@ -260,7 +262,7 @@ func getDaemonHostsAndIndexBySubnet(ctx *ReviewContext) (hostCmds bool, dbHosts
 		return false, dbHosts, nil
 	}
 	if _, _, present := ctx.subjectDaemon.KeaDaemon.Config.GetHooksLibrary("libdhcp_host_cmds"); present {
-		hosts, _, err := dbmodel.GetHostsByDaemonID(ctx.db, ctx.subjectDaemon.ID, "api")
+		hosts, _, err := dbmodel.GetHostsByDaemonID(ctx.db, ctx.subjectDaemon.ID, dbmodel.HostDataSourceAPI)
 		if err != nil {
 			return present, dbHosts, err
 		}
@@ -593,3 +595,239 @@ func reservationsOutOfPool(ctx *ReviewContext) (*Report, error) {
 	}
 	return checkDHCPv6ReservationsOutOfPool(ctx)
 }
+
+type minimalSubnet struct {
+	ID     int64
+	Subnet string
+}
+
+type minimalSubnetPair struct {
+	parent minimalSubnet
+	child  minimalSubnet
+}
+
+// The checker validates that subnets (global or from shared networks) don't overlap.
+func subnetsOverlapping(ctx *ReviewContext) (*Report, error) {
+	if ctx.subjectDaemon.Name != dbmodel.DaemonNameDHCPv4 &&
+		ctx.subjectDaemon.Name != dbmodel.DaemonNameDHCPv6 {
+		return nil, errors.Errorf("unsupported daemon %s", ctx.subjectDaemon.Name)
+	}
+
+	config := ctx.subjectDaemon.KeaDaemon.Config
+
+	var decodedSubnets []minimalSubnet
+	// Global subnets.
+	err := config.DecodeTopLevelSubnets(&decodedSubnets)
+	if err != nil {
+		return nil, err
+	}
+
+	// Subnets belonging to the shared networks.
+	type minimalSharedNetwork struct {
+		Subnet4 []minimalSubnet
+		Subnet6 []minimalSubnet
+	}
+	var decodedSharedNetworks []minimalSharedNetwork
+	err = config.DecodeSharedNetworks(&decodedSharedNetworks)
+	if err != nil {
+		return nil, err
+	}
+
+	for _, sharedNetwork := range decodedSharedNetworks {
+		decodedSubnets = append(decodedSubnets, sharedNetwork.Subnet4...)
+		decodedSubnets = append(decodedSubnets, sharedNetwork.Subnet6...)
+	}
+
+	// Limits the overlaps count to avoid producing too huge review message.
+	maxOverlaps := 10
+	overlaps := findOverlaps(decodedSubnets, maxOverlaps)
+	if len(overlaps) == 0 {
+		return nil, nil
+	}
+
+	maxExceedMessage := ""
+	if len(overlaps) == maxOverlaps {
+		maxExceedMessage = " at least"
+	}
+
+	overlappingMessages := make([]string, len(overlaps))
+	for i, overlap := range overlaps {
+		parentID := ""
+		if overlap.parent.ID != 0 {
+			parentID = fmt.Sprintf(" (subnet-id %d)", overlap.parent.ID)
+		}
+		childID := ""
+		if overlap.child.ID != 0 {
+			childID = fmt.Sprintf(" (subnet-id %d)", overlap.child.ID)
+		}
+
+		message := fmt.Sprintf("%d. %s%s is overlapped by %s%s", i+1,
+			overlap.parent.Subnet, parentID,
+			overlap.child.Subnet, childID)
+		overlappingMessages[i] = message
+	}
+	overlapMessage := strings.Join(overlappingMessages, "; ")
+
+	return NewReport(ctx, fmt.Sprintf("Kea {daemon} configuration includes%s %s. "+
+		"It means that the DHCP clients in different subnets may be assigned the same IP addresses.\n%s",
+		maxExceedMessage, storkutil.FormatNoun(int64(len(overlaps)), "overlapping subnet pair", "s"), overlapMessage)).
+		referencingDaemon(ctx.subjectDaemon).
+		create()
+}
+
+// Search for prefix overlaps in the provided set of subnets.
+// The execution is stopped early if an expected name of founded overlaps is
+// reached.
+func findOverlaps(subnets []minimalSubnet, maxOverlaps int) (overlaps []minimalSubnetPair) {
+	// Pair of the subnet and its binary prefix.
+	type subnetWithPrefix struct {
+		subnet       minimalSubnet
+		binaryPrefix string
+	}
+
+	// Calculates the binary prefixes for all subnets.
+	subnetPrefixes := make([]subnetWithPrefix, len(subnets))
+
+	for i, subnet := range subnets {
+		cidr := storkutil.ParseIP(subnet.Subnet)
+		if cidr == nil || !cidr.Prefix {
+			continue
+		}
+		binaryPrefix := cidr.GetNetworkPrefixAsBinary()
+
+		subnetPrefixes[i] = subnetWithPrefix{
+			subnet:       subnet,
+			binaryPrefix: binaryPrefix,
+		}
+	}
+
+	// Sorts prefixes from the shortest (the most general masks) to the longest
+	// (the most specific masks).
+	sort.Slice(subnetPrefixes, func(i, j int) bool {
+		return len(subnetPrefixes[i].binaryPrefix) <= len(subnetPrefixes[j].binaryPrefix)
+	})
+
+	for outerIdx, outer := range subnetPrefixes {
+		for innerIdx, inner := range subnetPrefixes {
+			// The prefixes are sorted by length. The prefix length is equal to
+			// the subnet mask in bits. For a given prefix with length X, we
+			// need only check the prefixes with lengths equal to or greater
+			// than X. It means that we need to check only the following
+			// prefixes.
+			if outerIdx >= innerIdx {
+				continue
+			}
+
+			// Checks if the outer prefix contains the inner prefix. It happens
+			// when the inner prefix's binary representation starts with the
+			// outer prefix's binary representation.
+			if strings.HasPrefix(inner.binaryPrefix, outer.binaryPrefix) {
+				overlaps = append(overlaps, minimalSubnetPair{
+					parent: outer.subnet,
+					child:  inner.subnet,
+				})
+
+				// Checks if the overlap limit is exceed.
+				if len(overlaps) == maxOverlaps {
+					return
+				}
+			}
+		}
+	}
+	return overlaps
+}
+
+// The checker validates that all subnet prefixes are in canonical form.
+func canonicalPrefixes(ctx *ReviewContext) (*Report, error) {
+	if ctx.subjectDaemon.Name != dbmodel.DaemonNameDHCPv4 &&
+		ctx.subjectDaemon.Name != dbmodel.DaemonNameDHCPv6 {
+		return nil, errors.Errorf("unsupported daemon %s", ctx.subjectDaemon.Name)
+	}
+
+	config := ctx.subjectDaemon.KeaDaemon.Config
+
+	var decodedSubnets []minimalSubnet
+	// Global subnets.
+	err := config.DecodeTopLevelSubnets(&decodedSubnets)
+	if err != nil {
+		return nil, err
+	}
+
+	// Subnets belonging to the shared networks.
+	type minimalSharedNetwork struct {
+		Subnet4 []minimalSubnet
+		Subnet6 []minimalSubnet
+	}
+	var decodedSharedNetworks []minimalSharedNetwork
+	err = config.DecodeSharedNetworks(&decodedSharedNetworks)
+	if err != nil {
+		return nil, err
+	}
+
+	for _, sharedNetwork := range decodedSharedNetworks {
+		decodedSubnets = append(decodedSubnets, sharedNetwork.Subnet4...)
+		decodedSubnets = append(decodedSubnets, sharedNetwork.Subnet6...)
+	}
+
+	maxIssues := 10
+	var issues []string
+
+	for _, decodedSubnet := range decodedSubnets {
+		prefix, ok := getCanonicalPrefix(decodedSubnet.Subnet)
+		if ok {
+			continue
+		}
+
+		subnetID := ""
+		if decodedSubnet.ID != 0 {
+			subnetID = fmt.Sprintf("[%d] ", decodedSubnet.ID)
+		}
+
+		issue := fmt.Sprintf("%d. %s%s is invalid prefix", len(issues)+1, subnetID, decodedSubnet.Subnet)
+
+		if prefix != "" {
+			issue = fmt.Sprintf("%s, expected: %s", issue, prefix)
+		}
+
+		issues = append(issues, issue)
+
+		if len(issues) == maxIssues {
+			break
+		}
+	}
+
+	if len(issues) == 0 {
+		return nil, nil
+	}
+
+	maxExceedMessage := ""
+	if len(issues) == maxIssues {
+		maxExceedMessage = " at least"
+	}
+
+	hintMessage := strings.Join(issues, "; ")
+
+	return NewReport(ctx, fmt.Sprintf("Kea {daemon} configuration contains%s %s. "+
+		"Kea accepts non-canonical prefix forms, which may lead to duplicates "+
+		"if two subnets have the same prefix specified in different forms. "+
+		"Use canonical forms to ensure that Kea properly identifies and "+
+		"validates subnet prefixes to avoid duplication or overlap.\n%s",
+		maxExceedMessage, storkutil.FormatNoun(int64(len(issues)), "non-canonical prefix", "es"), hintMessage)).
+		referencingDaemon(ctx.subjectDaemon).
+		create()
+}
+
+// Returns the prefix with zeros on masked bits. If it was already valid, return the true status.
+func getCanonicalPrefix(prefix string) (string, bool) {
+	candidate := storkutil.ParseIP(prefix)
+	if candidate == nil {
+		return "", false
+	}
+	expected := storkutil.ParseIP(candidate.NetworkPrefix)
+	for i, b := range candidate.IP {
+		if b != expected.IP[i] {
+			return candidate.GetNetworkPrefixWithLength(), false
+		}
+	}
+	return candidate.GetNetworkPrefixWithLength(), true
+}
