@@ -7,13 +7,20 @@ import (
 	"github.com/stretchr/testify/require"
 	keaconfig "isc.org/stork/appcfg/kea"
 	dbmodel "isc.org/stork/server/database/model"
+	dbtest "isc.org/stork/server/database/test"
 	"isc.org/stork/server/gen/models"
 	storkutil "isc.org/stork/util"
 )
 
-// Test successful conversion of DHCP options received over the REST API to
+// Test successful conversion of DHCPv4 options received over the REST API to
 // the database model.
-func TestFlattenDHCPOptions(t *testing.T) {
+func TestFlattenDHCPv4Options(t *testing.T) {
+	db, dbSettings, teardown := dbtest.SetupDatabaseTestCase(t)
+	defer teardown()
+
+	rapi, err := NewRestAPI(dbSettings, db, dbmodel.NewDHCPOptionDefinitionLookup())
+	require.NoError(t, err)
+
 	// Create options with suboptions and different option field types.
 	restOptions := []*models.DHCPOption{
 		{
@@ -100,15 +107,43 @@ func TestFlattenDHCPOptions(t *testing.T) {
 						},
 					},
 					Universe: 4,
+					Options: []*models.DHCPOption{
+						{
+							Code:        5,
+							Encapsulate: "option-1002.4.5",
+							Fields: []*models.DHCPOptionField{
+								{
+									FieldType: keaconfig.StringField,
+									Values:    []string{"baz"},
+								},
+							},
+							Universe: 4,
+							Options: []*models.DHCPOption{
+								// This option is at 4-th recursion level, thus it should be
+								// excluded from the result.
+								{
+									Code:        6,
+									Encapsulate: "option-1002.4.5.6",
+									Fields: []*models.DHCPOptionField{
+										{
+											FieldType: keaconfig.Uint32Field,
+											Values:    []string{"12"},
+										},
+									},
+									Universe: 4,
+								},
+							},
+						},
+					},
 				},
 			},
 			Universe: 4,
 		},
 	}
 	// Convert and flatten the structure.
-	options, err := flattenDHCPOptions("dhcp4", restOptions)
+	options, err := rapi.flattenDHCPOptions("dhcp4", restOptions, 0)
 	require.NoError(t, err)
-	require.Len(t, options, 6)
+	require.Len(t, options, 7)
 
 	// Sort the options by code because their order is not guaranteed.
 	sort.Slice(options, func(i, j int) bool {
@@ -160,28 +195,124 @@ func TestFlattenDHCPOptions(t *testing.T) {
 	require.Equal(t, "option-1002.4", options[3].Encapsulate)
 	require.Equal(t, storkutil.IPv4, options[3].Universe)
 
-	require.True(t, options[4].AlwaysSend)
-	require.EqualValues(t, 1001, options[4].Code)
+	require.False(t, options[4].AlwaysSend)
+	require.EqualValues(t, 5, options[4].Code)
 	require.Len(t, options[4].Fields, 1)
 	require.Len(t, options[4].Fields[0].Values, 1)
-	require.EqualValues(t, "foo", options[4].Fields[0].Values[0])
-	require.Equal(t, "option-1001", options[4].Encapsulate)
-	require.Equal(t, "dhcp4", options[4].Space)
+	require.EqualValues(t, "baz", options[4].Fields[0].Values[0])
+	require.Equal(t, "option-1002.4.5", options[4].Encapsulate)
+	require.Equal(t, "option-1002.4", options[4].Space)
 	require.Equal(t, storkutil.IPv4, options[4].Universe)
 
-	require.False(t, options[5].AlwaysSend)
-	require.EqualValues(t, 1002, options[5].Code)
+	require.True(t, options[5].AlwaysSend)
+	require.EqualValues(t, 1001, options[5].Code)
 	require.Len(t, options[5].Fields, 1)
 	require.Len(t, options[5].Fields[0].Values, 1)
-	require.EqualValues(t, 755, options[5].Fields[0].Values[0])
-	require.Equal(t, "option-1002", options[5].Encapsulate)
+	require.EqualValues(t, "foo", options[5].Fields[0].Values[0])
+	require.Equal(t, "option-1001", options[5].Encapsulate)
 	require.Equal(t, "dhcp4", options[5].Space)
 	require.Equal(t, storkutil.IPv4, options[5].Universe)
+
+	require.False(t, options[6].AlwaysSend)
+	require.EqualValues(t, 1002, options[6].Code)
+	require.Len(t, options[6].Fields, 1)
+	require.Len(t, options[6].Fields[0].Values, 1)
+	require.EqualValues(t, 755, options[6].Fields[0].Values[0])
+	require.Equal(t, "option-1002", options[6].Encapsulate)
+	require.Equal(t, "dhcp4", options[6].Space)
+	require.Equal(t, storkutil.IPv4, options[6].Universe)
+}
+
+// Test successful conversion of standard DHCPv6 options received over the
+// REST API to the database model. Standard options have their definitions
+// used to set the encapsulate field.
+func TestFlattenDHCPv6Options(t *testing.T) {
+	db, dbSettings, teardown := dbtest.SetupDatabaseTestCase(t)
+	defer teardown()
+
+	rapi, err := NewRestAPI(dbSettings, db, dbmodel.NewDHCPOptionDefinitionLookup())
+	require.NoError(t, err)
+
+	// Create options with suboptions and different option field types.
+	restOptions := []*models.DHCPOption{
+		{
+			AlwaysSend:  true,
+			Code:        94,
+			Encapsulate: "option-94",
+			Fields:      []*models.DHCPOptionField{},
+			Options: []*models.DHCPOption{
+				{
+					Code:        89,
+					Encapsulate: "option-94.89",
+					Fields: []*models.DHCPOptionField{
+						{
+							FieldType: keaconfig.Uint8Field,
+							Values:    []string{"1"},
+						},
+					},
+					Options: []*models.DHCPOption{
+						{
+							Code:        93,
+							Encapsulate: "option-94.89.93",
+							Fields: []*models.DHCPOptionField{
+								{
+									FieldType: keaconfig.Uint8Field,
+									Values:    []string{"2"},
+								},
+							},
+							Universe: 6,
+						},
+					},
+					Universe: 6,
+				},
+			},
+			Universe: 6,
+		},
+	}
+	// Convert and flatten the structure.
+	options, err := rapi.flattenDHCPOptions("dhcp6", restOptions, 0)
+	require.NoError(t, err)
+	require.Len(t, options, 3)
+
+	// Sort the options by code because their order is not guaranteed.
+	sort.Slice(options, func(i, j int) bool {
+		return options[i].Code < options[j].Code
+	})
+	require.False(t, options[0].AlwaysSend)
+	require.EqualValues(t, 89, options[0].Code)
+	require.Len(t, options[0].Fields, 1)
+	require.Len(t, options[0].Fields[0].Values, 1)
+	require.EqualValues(t, 1, options[0].Fields[0].Values[0])
+	require.Equal(t, "s46-cont-mape-options", options[0].Space)
+	require.Equal(t, "s46-rule-options", options[0].Encapsulate)
+	require.Equal(t, storkutil.IPv6, options[0].Universe)
+
+	require.False(t, options[1].AlwaysSend)
+	require.EqualValues(t, 93, options[1].Code)
+	require.Len(t, options[1].Fields, 1)
+	require.Len(t, options[1].Fields[0].Values, 1)
+	require.EqualValues(t, 2, options[1].Fields[0].Values[0])
+	require.Equal(t, "s46-rule-options", options[1].Space)
+	require.Empty(t, options[1].Encapsulate)
+	require.Equal(t, storkutil.IPv6, options[1].Universe)
+
+	require.True(t, options[2].AlwaysSend)
+	require.EqualValues(t, 94, options[2].Code)
+	require.Empty(t, options[2].Fields)
+	require.Equal(t, "dhcp6", options[2].Space)
+	require.Equal(t, "s46-cont-mape-options", options[2].Encapsulate)
+	require.Equal(t, storkutil.IPv6, options[2].Universe)
 }
 
 // Test negative scenarios of conversion of the DHCP options from the
 // REST API format to the database model.
 func TestFlattenDHCPOptionsInvalidValues(t *testing.T) {
+	db, dbSettings, teardown := dbtest.SetupDatabaseTestCase(t)
+	defer teardown()
+
+	rapi, err := NewRestAPI(dbSettings, db, dbmodel.NewDHCPOptionDefinitionLookup())
+	require.NoError(t, err)
+
 	type test struct {
 		testName  string
 		fieldType string
@@ -219,7 +350,7 @@ func TestFlattenDHCPOptionsInvalidValues(t *testing.T) {
 					},
 				},
 			}
-			options, err := flattenDHCPOptions("dhcp4", restOptions)
+			options, err := rapi.flattenDHCPOptions("dhcp4", restOptions, 0)
 			require.Error(t, err)
 			require.Nil(t, options)
 		})
@@ -228,6 +359,12 @@ func TestFlattenDHCPOptionsInvalidValues(t *testing.T) {
 
 // Test that a DHCP option model is successfully converted to a REST API format.
 func TestUnflattenDHCPOptions(t *testing.T) {
+	db, dbSettings, teardown := dbtest.SetupDatabaseTestCase(t)
+	defer teardown()
+
+	rapi, err := NewRestAPI(dbSettings, db, dbmodel.NewDHCPOptionDefinitionLookup())
+	require.NoError(t, err)
+
 	options := []dbmodel.DHCPOption{
 		{
 			AlwaysSend:  true,
@@ -252,10 +389,22 @@ func TestUnflattenDHCPOptions(t *testing.T) {
 			Space:       "option-1001",
 			Encapsulate: "option-1001.1",
 		},
+		{
+			AlwaysSend: false,
+			Code:       2,
+			Fields: []dbmodel.DHCPOptionField{
+				{
+					FieldType: keaconfig.Uint32Field,
+					Values:    []any{22},
+				},
+			},
+			Space:       "option-1001.1",
+			Encapsulate: "option-1001.1.2",
+		},
 	}
 
 	// Convert.
-	restOptions := unflattenDHCPOptions(options, "", 0)
+	restOptions := rapi.unflattenDHCPOptions(options, "", 0)
 	require.Len(t, restOptions, 1)
 	require.True(t, restOptions[0].AlwaysSend)
 	require.EqualValues(t, 1001, restOptions[0].Code)
@@ -266,7 +415,7 @@ func TestUnflattenDHCPOptions(t *testing.T) {
 	require.Equal(t, "foo", restOptions[0].Fields[0].Values[0])
 	require.Len(t, restOptions[0].Options, 1)
 
-	// Suboption
+	// First level suboption.
 	require.Len(t, restOptions[0].Options, 1)
 	require.False(t, restOptions[0].Options[0].AlwaysSend)
 	require.EqualValues(t, 1, restOptions[0].Options[0].Code)
@@ -275,11 +424,27 @@ func TestUnflattenDHCPOptions(t *testing.T) {
 	require.Len(t, restOptions[0].Options[0].Fields[0].Values, 1)
 	require.Equal(t, "11", restOptions[0].Options[0].Fields[0].Values[0])
 	require.Equal(t, "option-1001.1", restOptions[0].Options[0].Encapsulate)
+
+	// Second level suboption.
+	require.Len(t, restOptions[0].Options[0].Options, 1)
+	require.False(t, restOptions[0].Options[0].Options[0].AlwaysSend)
+	require.EqualValues(t, 2, restOptions[0].Options[0].Options[0].Code)
+	require.Len(t, restOptions[0].Options[0].Options[0].Fields, 1)
+	require.Equal(t, keaconfig.Uint32Field, restOptions[0].Options[0].Options[0].Fields[0].FieldType)
+	require.Len(t, restOptions[0].Options[0].Options[0].Fields[0].Values, 1)
+	require.Equal(t, "22", restOptions[0].Options[0].Options[0].Fields[0].Values[0])
+	require.Equal(t, "option-1001.1.2", restOptions[0].Options[0].Options[0].Encapsulate)
 }
 
 // Test that option field values of different types are correctly converted
 // into REST API format.
 func TestUnflattenDHCPOptionsVariousFieldTypes(t *testing.T) {
+	db, dbSettings, teardown := dbtest.SetupDatabaseTestCase(t)
+	defer teardown()
+
+	rapi, err := NewRestAPI(dbSettings, db, dbmodel.NewDHCPOptionDefinitionLookup())
+	require.NoError(t, err)
+
 	type test struct {
 		testName    string
 		fieldType   string
@@ -315,7 +480,7 @@ func TestUnflattenDHCPOptionsVariousFieldTypes(t *testing.T) {
 					},
 				},
 			}
-			restOptions := unflattenDHCPOptions(options, "", 0)
+			restOptions := rapi.unflattenDHCPOptions(options, "", 0)
 			require.Len(t, restOptions, 1)
 			require.Len(t, restOptions[0].Fields, 1)
 			require.Equal(t, fieldType, restOptions[0].Fields[0].FieldType)
@@ -327,6 +492,12 @@ func TestUnflattenDHCPOptionsVariousFieldTypes(t *testing.T) {
 // Test that maximum recursion level is respected while converting DHCP options
 // to the REST API format.
 func TestUnflattenDHCPOptionsRecursionLevel(t *testing.T) {
+	db, dbSettings, teardown := dbtest.SetupDatabaseTestCase(t)
+	defer teardown()
+
+	rapi, err := NewRestAPI(dbSettings, db, dbmodel.NewDHCPOptionDefinitionLookup())
+	require.NoError(t, err)
+
 	options := []dbmodel.DHCPOption{
 		{
 			Code:        1001,
@@ -338,13 +509,20 @@ func TestUnflattenDHCPOptionsRecursionLevel(t *testing.T) {
 			Encapsulate: "option-1001.1",
 		},
 		{
-			Code:  2,
-			Space: "option-1001.1",
+			Code:        2,
+			Space:       "option-1001.1",
+			Encapsulate: "option-1001.1.2",
+		},
+		{
+			Code:        3,
+			Space:       "option-1001.1.2",
+			Encapsulate: "option-1001.1.3",
 		},
 	}
 
-	restOptions := unflattenDHCPOptions(options, "", 0)
+	restOptions := rapi.unflattenDHCPOptions(options, "", 0)
 	require.Len(t, restOptions, 1)
 	require.Len(t, restOptions[0].Options, 1)
-	require.Zero(t, restOptions[0].Options[0].Options)
+	require.Len(t, restOptions[0].Options[0].Options, 1)
+	require.Zero(t, restOptions[0].Options[0].Options[0].Options)
 }
