@@ -2,11 +2,14 @@ package server
 
 import (
 	"errors"
+	"sync"
 
+	"github.com/go-pg/pg/v10"
 	flags "github.com/jessevdk/go-flags"
 	log "github.com/sirupsen/logrus"
 
 	"isc.org/stork"
+	keaconfig "isc.org/stork/appcfg/kea"
 	"isc.org/stork/server/agentcomm"
 	"isc.org/stork/server/apps"
 	"isc.org/stork/server/apps/bind9"
@@ -43,6 +46,7 @@ type StorkServer struct {
 
 	Pullers *apps.Pullers
 
+	InitialPullerInterval int64
 	EnableMetricsEndpoint bool
 	MetricsCollector      metrics.Collector
 
@@ -50,13 +54,16 @@ type StorkServer struct {
 
 	ReviewDispatcher configreview.Dispatcher
 
-	ConfigManager config.Manager
+	ConfigManager              config.Manager
+	DHCPOptionDefinitionLookup keaconfig.DHCPOptionDefinitionLookup
+	shutdownOnce               sync.Once
 }
 
 // Global server settings (called application settings in go-flags nomenclature).
 type Settings struct {
-	Version               bool `short:"v" long:"version" description:"Show software version"`
-	EnableMetricsEndpoint bool `short:"m" long:"metrics" description:"Enable Prometheus /metrics endpoint (no auth)" env:"STORK_SERVER_ENABLE_METRICS"`
+	Version               bool  `short:"v" long:"version" description:"Show software version"`
+	EnableMetricsEndpoint bool  `short:"m" long:"metrics" description:"Enable Prometheus /metrics endpoint (no auth)" env:"STORK_SERVER_ENABLE_METRICS"`
+	InitialPullerInterval int64 `long:"initial-puller-interval" description:"Initial interval used by pullers fetching data from Kea. If not provided the recommended values for each puller are used." env:"STORK_SERVER_INITIAL_PULLER_INTERVAL"`
 }
 
 // Parse the command line arguments into GO structures.
@@ -98,6 +105,7 @@ func (ss *StorkServer) ParseArgs() (command Command, err error) {
 	}
 
 	ss.EnableMetricsEndpoint = serverSettings.EnableMetricsEndpoint
+	ss.InitialPullerInterval = serverSettings.InitialPullerInterval
 
 	if serverSettings.Version {
 		// If user specified --version or -v, print the version and quit.
@@ -119,8 +127,9 @@ func NewStorkServer() (ss *StorkServer, command Command, err error) {
 }
 
 // Establishes a database connection, runs the background pullers, and
-// prepares the REST API.
-func (ss *StorkServer) Bootstrap() (err error) {
+// prepares the REST API. The reload flag indicates if the server is
+// starting up (reload=false) or it is being reloaded (reload=true).
+func (ss *StorkServer) Bootstrap(reload bool) (err error) {
 	// setup database connection
 	ss.DB, err = dbops.NewPgDB(&ss.DBSettings)
 	if err != nil {
@@ -128,7 +137,7 @@ func (ss *StorkServer) Bootstrap() (err error) {
 	}
 
 	// initialize stork settings
-	err = dbmodel.InitializeSettings(ss.DB)
+	err = dbmodel.InitializeSettings(ss.DB, ss.InitialPullerInterval)
 	if err != nil {
 		return err
 	}
@@ -170,8 +179,12 @@ func (ss *StorkServer) Bootstrap() (err error) {
 
 	ss.Pullers = &apps.Pullers{}
 
+	// This instance provides functions to search for option definitions, both in the
+	// database and among the standard options. It is required by the config manager.
+	ss.DHCPOptionDefinitionLookup = dbmodel.NewDHCPOptionDefinitionLookup()
+
 	// setup apps state puller
-	ss.Pullers.AppsStatePuller, err = apps.NewStatePuller(ss.DB, ss.Agents, ss.EventCenter, ss.ReviewDispatcher)
+	ss.Pullers.AppsStatePuller, err = apps.NewStatePuller(ss.DB, ss.Agents, ss.EventCenter, ss.ReviewDispatcher, ss.DHCPOptionDefinitionLookup)
 	if err != nil {
 		return err
 	}
@@ -189,7 +202,7 @@ func (ss *StorkServer) Bootstrap() (err error) {
 	}
 
 	// Setup Kea hosts puller.
-	ss.Pullers.KeaHostsPuller, err = kea.NewHostsPuller(ss.DB, ss.Agents, ss.ReviewDispatcher)
+	ss.Pullers.KeaHostsPuller, err = kea.NewHostsPuller(ss.DB, ss.Agents, ss.ReviewDispatcher, ss.DHCPOptionDefinitionLookup)
 	if err != nil {
 		return err
 	}
@@ -210,12 +223,19 @@ func (ss *StorkServer) Bootstrap() (err error) {
 		log.Warn("The metric endpoint is disabled (it can be enabled with the -m flag)")
 	}
 
-	ss.ConfigManager = apps.NewManager(ss.DB, ss.Agents)
+	// Create the config manager instance. It takes config.ManagerAccessors interface
+	// as a parameter. The manager uses this interface to setup its state. For example,
+	// it stores the instance of the DHCP option definition lookup. Note, that it is
+	// important to maintain one instance of the lookup because it applies indexing
+	// on the option definitions it returns. Indexing should be done only once at
+	// server startup.
+	ss.ConfigManager = apps.NewManager(ss)
 
 	// setup ReST API service
 	r, err := restservice.NewRestAPI(&ss.RestAPISettings, &ss.DBSettings,
 		ss.DB, ss.Agents, ss.EventCenter,
-		ss.Pullers, ss.ReviewDispatcher, ss.MetricsCollector, ss.ConfigManager)
+		ss.Pullers, ss.ReviewDispatcher, ss.MetricsCollector, ss.ConfigManager,
+		ss.DHCPOptionDefinitionLookup)
 	if err != nil {
 		ss.Pullers.HAStatusPuller.Shutdown()
 		ss.Pullers.KeaHostsPuller.Shutdown()
@@ -231,7 +251,10 @@ func (ss *StorkServer) Bootstrap() (err error) {
 	}
 	ss.RestAPI = r
 
-	ss.EventCenter.AddInfoEvent("started Stork Server", "version: "+stork.Version+"\nbuild date: "+stork.BuildDate)
+	// Do not issue the event if we're only reloading the server.
+	if !reload {
+		ss.EventCenter.AddInfoEvent("started Stork Server", "version: "+stork.Version+"\nbuild date: "+stork.BuildDate)
+	}
 
 	return nil
 }
@@ -245,22 +268,51 @@ func (ss *StorkServer) Serve() {
 	}
 }
 
-// Shutdown for Stork Server state.
-func (ss *StorkServer) Shutdown() {
-	ss.EventCenter.AddInfoEvent("shutting down Stork Server")
-	log.Println("Shutting down Stork Server")
-	ss.RestAPI.Shutdown()
-	ss.Pullers.HAStatusPuller.Shutdown()
-	ss.Pullers.KeaHostsPuller.Shutdown()
-	ss.Pullers.KeaStatsPuller.Shutdown()
-	ss.Pullers.Bind9StatsPuller.Shutdown()
-	ss.Pullers.AppsStatePuller.Shutdown()
-	ss.Agents.Shutdown()
-	ss.EventCenter.Shutdown()
-	ss.ReviewDispatcher.Shutdown()
-	if ss.MetricsCollector != nil {
-		ss.MetricsCollector.Shutdown()
-	}
-	ss.DB.Close()
-	log.Println("Stork Server shut down")
+// Shutdown for Stork Server state. The reload flag indicates if the
+// Shutdown is called as part of the server reload (reload=true) or
+// the process is terminating (reload=false).
+func (ss *StorkServer) Shutdown(reload bool) {
+	// If this function is called multiple times, make sure we shutdown
+	// only once.
+	ss.shutdownOnce.Do(func() {
+		// Do not issue the event when we're reloading instead of terminating
+		// the server process.
+		if !reload {
+			ss.EventCenter.AddInfoEvent("shutting down Stork Server")
+			log.Println("Shutting down Stork Server")
+		}
+		ss.RestAPI.Shutdown()
+		ss.Pullers.HAStatusPuller.Shutdown()
+		ss.Pullers.KeaHostsPuller.Shutdown()
+		ss.Pullers.KeaStatsPuller.Shutdown()
+		ss.Pullers.Bind9StatsPuller.Shutdown()
+		ss.Pullers.AppsStatePuller.Shutdown()
+		ss.Agents.Shutdown()
+		ss.EventCenter.Shutdown()
+		ss.ReviewDispatcher.Shutdown()
+		if ss.MetricsCollector != nil {
+			ss.MetricsCollector.Shutdown()
+		}
+		ss.DB.Close()
+
+		if !reload {
+			log.Println("Stork Server shut down")
+		}
+	})
+}
+
+// Returns an instance of the database handler used by the configuration manager.
+func (ss *StorkServer) GetDB() *pg.DB {
+	return ss.DB
+}
+
+// Returns an interface to the agents the manager communicates with.
+func (ss *StorkServer) GetConnectedAgents() agentcomm.ConnectedAgents {
+	return ss.Agents
+}
+
+// Returns an interface to the instance providing the DHCP option definition
+// lookup logic.
+func (ss *StorkServer) GetDHCPOptionDefinitionLookup() keaconfig.DHCPOptionDefinitionLookup {
+	return ss.DHCPOptionDefinitionLookup
 }
