@@ -3,6 +3,9 @@ from unittest.mock import MagicMock, patch
 from core.compose import ContainerExitedException, ContainerUnhealthyException, DockerCompose
 from tests.core.commons import subprocess_result_mock
 
+import pytest
+import yaml
+
 
 def test_command_contains_project_directory():
     compose = DockerCompose("project-dir")
@@ -105,8 +108,8 @@ def test_build_uses_build_arguments():
     # Act
     compose.build("foobar")
     build_cmd = " ".join(mock.call_args.kwargs["cmd"])
-    assert "-build-arg foo=bar"
-    assert "-build-arg baz=biz"
+    assert "-build-arg foo=bar" in build_cmd
+    assert "-build-arg baz=biz" in build_cmd
 
 
 def test_pull_uses_proper_command():
@@ -694,6 +697,83 @@ def test_wait_for_operational_exited():
         # Assert
         pass
 
+def test_get_pid():
+    # Arrange
+    compose = DockerCompose("project-dir")
+    call_command_mock = MagicMock()
+    call_command_mock.return_value = (0, "123", "")
+    compose._call_command = call_command_mock
+    # Act
+    pid = compose.get_pid("stork-agent", "kea-dhcp4")
+    # Assert
+    assert pid == 123
+    cmd = call_command_mock.call_args.kwargs["cmd"]
+    assert len(cmd) > 4
+    assert cmd[-4] == "stork-agent"
+    assert cmd[-3] == "supervisorctl"
+    assert cmd[-2] == "pid"
+    assert cmd[-1] == "kea-dhcp4"
+
+def test_get_pid_unparsable_pid():
+    # Arrange
+    compose = DockerCompose("project-dir")
+    call_command_mock = MagicMock()
+    call_command_mock.return_value = (0, "abc", "")
+    compose._call_command = call_command_mock
+    # Act
+    pid = compose.get_pid("stork-agent", "kea-dhcp4")
+    # Assert
+    assert pid is None
+
+def test_is_premium_reads_config():
+    # Arrange
+    compose = DockerCompose("project-dir")
+    mock = MagicMock()
+    config = {
+        'services': {
+            'foo': {
+                'profiles': [
+                    'test',
+                    'premium'
+                ]
+            },
+            'bar': {
+                'profiles': [
+                    'non-premium'
+                ]
+            }
+        }
+    }
+    config_yaml = yaml.safe_dump(config)
+    mock.return_value = (0, config_yaml, "")
+    compose._call_command = mock
+    base_cmd = compose.docker_compose_command()
+    # Act
+    is_foo_premium = compose.is_premium("foo")
+    is_bar_premium = compose.is_premium("bar")
+    # Assert
+    # Checks if config is memoized.
+    mock.assert_called_once()
+    cmd = mock.call_args.kwargs["cmd"]
+    assert " ".join(cmd).startswith(" ".join(base_cmd))
+    assert cmd[-1] == "config"
+    assert is_foo_premium
+    assert not is_bar_premium
+
+
+def test_is_premium_raises_for_unknown_service():
+    compose = DockerCompose("project-dir")
+    mock = MagicMock()
+    config = {
+        'services': {}
+    }
+    config_yaml = yaml.safe_dump(config)
+    mock.return_value = (0, config_yaml, "")
+    compose._call_command = mock
+    # Act & Assert
+    with pytest.raises(LookupError):
+        compose.is_premium("foo")
+
 
 @patch("subprocess.run")
 def test_call_command_passes_command(patch: MagicMock):
@@ -703,7 +783,6 @@ def test_call_command_passes_command(patch: MagicMock):
     cmd = patch.call_args.args[0]
     assert tuple(cmd) == ("foo", "bar")
 
-
 @patch("subprocess.run")
 def test_call_command_adds_env_vars(patch: MagicMock):
     compose = DockerCompose("project-dir", env_vars=dict(global_foo="1"))
