@@ -3,7 +3,7 @@ import { Component, EventEmitter, Input, Output } from '@angular/core'
 import { ConfirmationService, MessageService } from 'primeng/api'
 
 import { DHCPService } from '../backend/api/api'
-import { durationToString, epochToLocal } from '../utils'
+import { durationToString, epochToLocal, getErrorMessage } from '../utils'
 
 enum HostReservationUsage {
     Conflicted = 1,
@@ -35,6 +35,16 @@ enum HostReservationUsage {
     styleUrls: ['./host-tab.component.sass'],
 })
 export class HostTabComponent {
+    /**
+     * An event emitter notifying a parent that user has clicked the
+     * Edit button to modify the host reservation.
+     */
+    @Output() hostEditBegin = new EventEmitter<any>()
+
+    /**
+     * An event emitter notifying a parent that user has clicked the
+     * Delete button to delete the host reservation.
+     */
     @Output() hostDelete = new EventEmitter<any>()
 
     Usage = HostReservationUsage
@@ -178,10 +188,7 @@ export class HostTabComponent {
             (err) => {
                 // Finished searching the leases.
                 this._leasesSearchStatus.set(hostId, false)
-                let msg = err.statusText
-                if (err.error && err.error.message) {
-                    msg = err.error.message
-                }
+                const msg = getErrorMessage(err)
                 this.msgService.add({
                     severity: 'error',
                     summary: 'Error searching leases for the host',
@@ -393,6 +400,16 @@ export class HostTabComponent {
         this._fetchLeases(this.host.id)
     }
 
+    /**
+     * Event handler called when user begins host editing.
+     *
+     * It emits an event to the parent component to notify that host is
+     * is now edited.
+     */
+    onHostEditBegin(): void {
+        this.hostEditBegin.emit(this.host)
+    }
+
     /*
      * Displays a dialog to confirm host deletion.
      */
@@ -431,13 +448,7 @@ export class HostTabComponent {
                 // Re-enable the delete button.
                 this.hostDeleted = false
                 // Issues with deleting the host.
-                let msg = err.statusText
-                if (err.error && err.error.message) {
-                    msg = err.error.message
-                }
-                if (!msg) {
-                    msg = `status: ${err.status}`
-                }
+                const msg = getErrorMessage(err)
                 this.msgService.add({
                     severity: 'error',
                     summary: 'Cannot delete the host',
@@ -446,4 +457,15 @@ export class HostTabComponent {
                 })
             })
     }
+
+    /**
+     * Checks if all DHCP servers owning the reservation have equal set of
+     * DHCP options.
+     *
+     * @returns true, if all DHCP servers have equal option set hashes, false
+     *          otherwise.
+     */
+    allDaemonsHaveEqualDhcpOptions(): boolean {
+        return this.host.localHosts.every((lh) => lh.optionsHash === this.host.localHosts[0].optionsHash)
+    }
 }
