@@ -1,5 +1,5 @@
 import { Component, OnInit } from '@angular/core'
-import { FormBuilder, FormGroup, Validators } from '@angular/forms'
+import { UntypedFormBuilder, UntypedFormGroup, Validators } from '@angular/forms'
 import { Router } from '@angular/router'
 
 import { MessageService } from 'primeng/api'
@@ -7,6 +7,7 @@ import { PasswordModule } from 'primeng/password'
 
 import { UsersService } from '../backend/api/api'
 import { AuthService } from '../auth.service'
+import { getErrorMessage } from '../utils'
 
 /**
  * This component allows the logged user to change the password.
@@ -19,11 +20,11 @@ import { AuthService } from '../auth.service'
 export class PasswordChangePageComponent implements OnInit {
     breadcrumbs = [{ label: 'User Profile' }, { label: 'Password Change' }]
 
-    passwordChangeForm: FormGroup
+    passwordChangeForm: UntypedFormGroup
 
     constructor(
         private router: Router,
-        private formBuilder: FormBuilder,
+        private formBuilder: UntypedFormBuilder,
         private usersApi: UsersService,
         private msgSrv: MessageService,
         private auth: AuthService
@@ -71,11 +72,7 @@ export class PasswordChangePageComponent implements OnInit {
                 })
             },
             (err) => {
-                console.info(err)
-                let msg = err.statusText
-                if (err.error && err.error.message) {
-                    msg = err.error.message
-                }
+                const msg = getErrorMessage(err)
                 this.msgSrv.add({
                     severity: 'error',
                     summary: 'Updating user password failed',
