@@ -1,4 +1,5 @@
 import { TestBed } from '@angular/core/testing'
+import { Subnet } from './backend'
 
 import { getTotalAddresses, getAssignedAddresses, parseSubnetsStatisticValues } from './subnets'
 
@@ -8,14 +9,10 @@ describe('subnets', () => {
     it('stats funcs should work for DHCPv4', () => {
         const subnet4 = {
             subnet: '192.168.0.0/24',
-            localSubnets: [
-                {
-                    stats: {
-                        'total-addresses': 4,
-                        'assigned-addresses': 2,
-                    },
-                },
-            ],
+            stats: {
+                'total-addresses': 4,
+                'assigned-addresses': 2,
+            },
         }
         const totalAddrs = getTotalAddresses(subnet4)
         expect(totalAddrs).toBe(4)
@@ -27,14 +24,10 @@ describe('subnets', () => {
     it('stats funcs should work for DHCPv6', () => {
         const subnet6 = {
             subnet: '3000::0/24',
-            localSubnets: [
-                {
-                    stats: {
-                        'total-nas': 4,
-                        'assigned-nas': BigInt('18446744073709551615'),
-                    },
-                },
-            ],
+            stats: {
+                'total-nas': 4,
+                'assigned-nas': BigInt('18446744073709551615'),
+            },
         }
         const totalAddrs = getTotalAddresses(subnet6)
         expect(totalAddrs).toBe(4)
@@ -48,15 +41,11 @@ describe('subnets', () => {
         const subnets6 = [
             {
                 subnet: '3000::0/24',
-                localSubnets: [
-                    {
-                        stats: {
-                            'total-nas': '4',
-                            'assigned-nas': '18446744073709551615',
-                            'total-pds': '',
-                        },
-                    },
-                ],
+                stats: {
+                    'total-nas': '4',
+                    'assigned-nas': '18446744073709551615',
+                    'total-pds': '',
+                },
             },
         ]
 
@@ -64,9 +53,9 @@ describe('subnets', () => {
         parseSubnetsStatisticValues(subnets6)
 
         // Assert
-        expect(subnets6[0].localSubnets[0].stats['total-nas']).toBe(BigInt('4') as any)
-        expect(subnets6[0].localSubnets[0].stats['assigned-nas']).toBe(BigInt('18446744073709551615') as any)
-        expect(subnets6[0].localSubnets[0].stats['total-pds']).toBe(BigInt(0) as any)
+        expect(subnets6[0].stats['total-nas']).toBe(BigInt('4') as any)
+        expect(subnets6[0].stats['assigned-nas']).toBe(BigInt('18446744073709551615') as any)
+        expect(subnets6[0].stats['total-pds']).toBe(BigInt(0) as any)
     })
 
     it('parse stats from non-string to big int', () => {
@@ -75,16 +64,12 @@ describe('subnets', () => {
         const subnets6 = [
             {
                 subnet: '3000::0/24',
-                localSubnets: [
-                    {
-                        stats: {
-                            'total-nas': true,
-                            'assigned-nas': 42,
-                            'declined-nas': obj,
-                            'assigned-pds': null,
-                        },
-                    },
-                ],
+                stats: {
+                    'total-nas': true,
+                    'assigned-nas': 42,
+                    'declined-nas': obj,
+                    'assigned-pds': null,
+                },
             },
         ]
 
@@ -92,10 +77,10 @@ describe('subnets', () => {
         parseSubnetsStatisticValues(subnets6)
 
         // Assert
-        expect(subnets6[0].localSubnets[0].stats['total-nas']).toBe(true)
-        expect(subnets6[0].localSubnets[0].stats['assigned-nas']).toBe(42)
-        expect(subnets6[0].localSubnets[0].stats['declined-nas']).toBe(obj)
-        expect(subnets6[0].localSubnets[0].stats['assigned-pds']).toBe(null)
+        expect(subnets6[0].stats['total-nas']).toBe(true)
+        expect(subnets6[0].stats['assigned-nas']).toBe(42)
+        expect(subnets6[0].stats['declined-nas']).toBe(obj)
+        expect(subnets6[0].stats['assigned-pds']).toBe(null)
     })
 
     it('parse stats from non-numeric string to big int', () => {
@@ -103,14 +88,10 @@ describe('subnets', () => {
         const subnets6 = [
             {
                 subnet: '3000::0/24',
-                localSubnets: [
-                    {
-                        stats: {
-                            'total-nas': 'abc',
-                            'assigned-nas': 'FF',
-                        },
-                    },
-                ],
+                stats: {
+                    'total-nas': 'abc',
+                    'assigned-nas': 'FF',
+                },
             },
         ]
 
@@ -118,8 +99,8 @@ describe('subnets', () => {
         parseSubnetsStatisticValues(subnets6)
 
         // Assert
-        expect(subnets6[0].localSubnets[0].stats['total-nas']).toBe('abc')
-        expect(subnets6[0].localSubnets[0].stats['assigned-nas']).toBe('FF')
+        expect(subnets6[0].stats['total-nas']).toBe('abc')
+        expect(subnets6[0].stats['assigned-nas']).toBe('FF')
     })
 
     it('parse stats for missing local subnets', () => {
