@@ -2,7 +2,7 @@ import { ComponentFixture, TestBed, waitForAsync } from '@angular/core/testing'
 
 import { UsersPageComponent } from './users-page.component'
 import { ActivatedRoute, Router, RouterModule } from '@angular/router'
-import { FormBuilder } from '@angular/forms'
+import { UntypedFormBuilder } from '@angular/forms'
 import { ServicesService, UsersService } from '../backend'
 import { HttpClientTestingModule } from '@angular/common/http/testing'
 import { MessageService } from 'primeng/api'
@@ -42,7 +42,7 @@ describe('UsersPageComponent', () => {
             ],
             declarations: [UsersPageComponent, BreadcrumbsComponent, HelpTipComponent],
             providers: [
-                FormBuilder,
+                UntypedFormBuilder,
                 UsersService,
                 ServicesService,
                 MessageService,
